@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/examples/buttongroups/main.cpp   2.3.0   edited 2001-01-26 $
+** $Id: qt/examples/buttongroups/main.cpp   2.3.2   edited 2001-06-12 $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -17,7 +17,7 @@ int main( int argc, char **argv )
 
     ButtonsGroups buttonsgroups;
     buttonsgroups.resize( 500, 250 );
-    buttonsgroups.setCaption( "Examples for Buttons and Groups" );
+    buttonsgroups.setCaption( "Qt Example - Buttongroups" );
     a.setMainWidget( &buttonsgroups );
     buttonsgroups.show();
 
