@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/examples/drawdemo/drawdemo.cpp   2.3.0   edited 2001-01-26 $
+** $Id: qt/examples/drawdemo/drawdemo.cpp   2.3.2   edited 2001-06-12 $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -234,7 +234,9 @@ void DrawView::printIt()
 {
 #ifndef QT_NO_PRINTER
     if ( printer->setup( this ) ) {
-        QPainter paint( printer );
+        QPainter paint;
+	if ( !paint.begin( printer ) )
+	    return;
         drawIt( &paint );
     }
 #endif
@@ -272,6 +274,7 @@ int main( int argc, char **argv )
     QApplication app( argc, argv );
     DrawView   draw;
     app.setMainWidget( &draw );
+    draw.setCaption("Qt Example - Drawdemo");
     draw.show();
     return app.exec();
 }
