@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/examples/iconview/main.cpp   2.3.0   edited 2001-01-26 $
+** $Id: qt/examples/iconview/main.cpp   2.3.2   edited 2001-06-12 $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -59,7 +59,7 @@ int main( int argc, char **argv )
 	item->setRenameEnabled( TRUE );
     }
 
-    qiconview.setCaption( "Iconview" );
+    qiconview.setCaption( "Qt Example - Iconview" );
 
     ListenDND listen_dnd( &qiconview );
     QObject::connect( &qiconview, SIGNAL( dropped( QDropEvent *, const QValueList<QIconDragItem> & ) ),
