@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/examples/listboxcombo/main.cpp   2.2.1   edited 2000-08-31 $
+** $Id: qt/examples/listboxcombo/main.cpp   2.3.2   edited 2001-06-12 $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -17,7 +17,7 @@ int main( int argc, char **argv )
 
     ListBoxCombo listboxcombo;
     listboxcombo.resize( 400, 270 );
-    listboxcombo.setCaption( "Examples for Listboxes and Comboboxes" );
+    listboxcombo.setCaption( "Qt Example - Listboxes and Comboboxes" );
     a.setMainWidget( &listboxcombo );
     listboxcombo.show();
 
