@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/examples/listviews/main.cpp   2.2.1   edited 2000-08-31 $
+** $Id: qt/examples/listviews/main.cpp   2.3.2   edited 2001-06-12 $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -17,7 +17,7 @@ int main( int argc, char **argv )
 
     ListViews listViews;
     listViews.resize( 640, 480 );
-    listViews.setCaption( "List View Example" );
+    listViews.setCaption( "Qt Example - Listview" );
     a.setMainWidget( &listViews );
     listViews.show();
 
