@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/examples/progressbar/main.cpp   2.2.1   edited 2000-08-31 $
+** $Id: qt/examples/progressbar/main.cpp   2.3.2   edited 2001-06-12 $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -16,7 +16,7 @@ int main(int argc,char **argv)
     QApplication a(argc,argv);
 
     ProgressBar progressbar;
-    progressbar.setCaption("Example for a ProgressBar");
+    progressbar.setCaption("Qt Example - ProgressBar");
     a.setMainWidget(&progressbar);
     progressbar.show();
 
