@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/examples/richtext/main.cpp   2.3.0   edited 2001-01-26 $
+** $Id: qt/examples/richtext/main.cpp   2.3.2   edited 2001-06-12 $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -17,7 +17,7 @@ int main( int argc, char **argv )
 
     MyRichText richtext;
     richtext.resize( 450, 350 );
-    richtext.setCaption( "Fortune" );
+    richtext.setCaption( "Qt Example - Richtext" );
     a.setMainWidget( &richtext );
     richtext.show();
 
