@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/examples/tooltip/main.cpp   2.2.1   edited 2000-08-31 $
+** $Id: qt/examples/tooltip/main.cpp   2.3.2   edited 2001-06-12 $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -16,7 +16,7 @@ int main( int argc, char ** argv )
     QApplication a( argc, argv );
 
     TellMe mw;
-    mw.setCaption( "Dynamic Tool Tip Demonstration" );
+    mw.setCaption( "Qt Example - Dynamic Tool Tips" );
     a.setMainWidget( &mw );
     mw.show();
     
