@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/examples/validator/main.cpp   2.3.0   edited 2001-01-26 $
+** $Id: qt/examples/validator/main.cpp   2.3.2   edited 2001-06-12 $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -15,7 +15,7 @@ int main( int argc, char ** argv ) {
     QApplication a( argc, argv );
     VW mw;
     a.setMainWidget( &mw );
-    mw.setCaption( "" );
+    mw.setCaption( "Qt Example - Validators" );
     mw.show();
     return a.exec();
 }
