@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/examples/wizard/main.cpp   2.3.0   edited 2001-01-26 $
+** $Id: qt/examples/wizard/main.cpp   2.3.2   edited 2001-06-12 $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -16,6 +16,6 @@ int main(int argc,char **argv)
     QApplication a(argc,argv);
 
     Wizard wizard;
-    wizard.setCaption("Wizard Example");
+    wizard.setCaption("Qt Example - Wizard");
     return wizard.exec();
 }
